import React from "react";
import { motion } from "framer-motion";

interface AnimatedTextProps {
  text: string;
  textClassName: string;
  className: string;
}

const AnimatedText: React.FC<AnimatedTextProps> = ({
  text,
  textClassName,
  className,
}) => {
  const characters = Array.from(text);

  const container = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: { staggerChildren: 0.04, delayChildren: 0.04 },
    },
  };
  const child = {
    visible: {
      opacity: 1,
      y: 0,
      x: 0,
      transition: {
        type: "spring",
        damping: 12,
        stiffness: 100,
      },
    },
    hidden: {
      opacity: 0,
      y: -15,
      x: 30,
      transition: {
        type: "spring",
        damping: 12,
        stiffness: 100,
      },
    },
  };

  return (
    <motion.div
      className={className}
      variants={container}
      initial="hidden"
      animate="visible"
    >
      {characters.map((letter, index) => (
        <motion.span
        className={textClassName}
        key={index}
        variants={child}
        >
          {letter}
        </motion.span>
      ))}
    </motion.div>
  );
};
export default AnimatedText;
