import React, { useState } from "react";
import Link from "next/link";
import { useRouter } from "next/router";
import CustomInput from "~/components/CustomInput";
import { IoReturnDownBackOutline } from "react-icons/io5";
import { api } from "~/utils/api";

const Login: React.FC = () => {
  const [ username, setUserName ] = useState<string>("");
  const [ password, setPassword ] = useState<string>("");

  const mutation = api.login.Login.useMutation({
    onSuccess: async () => {
      alert("Log in successful");
      await router.push("/");
    },
    onError: (error) => {
      console.log(error);
    },
  });

  const router = useRouter();

  const login = (event: React.FormEvent) => {
    event.preventDefault();
    mutation.mutate({
      username: username,
      password: password,
    });
  };

  const returnHome = () => {
    router.push("/")
			.catch((err) => console.log(`Failed to navigate to home page with error: ${err}`));
  };
  const goToSignup = () => {
    router.push("/Signup")
			.catch((err) => console.log(`Failed to navigate to signup page with error: ${err}`));
  }

  return (
    <div className="login-container">
      <IoReturnDownBackOutline onClick={returnHome} className="return" />
      <div className="header">
        <div className="login-logo">
          <img src="/finvis_logo.png" alt="finvis logo" />
        </div>
        <h1>FinVis</h1>
      </div>
      <form onSubmit={login} className="login-form" action="POST">
        <CustomInput
          type="text"
          onChange={(e) => {
            setUserName(e.target.value);
          }}
          placeholder="Username"
          required
        />
        <CustomInput
          type="text"
          onChange={(e) => {
            setPassword(e.target.value);
          }}
          placeholder="Password"
          required
        />
        <p className="forgot-pw">Forgot Password?</p>
        <input type="submit" value="Login" />
        <p className="go-to-signup">
          New here? <span onClick={goToSignup}>Create an Account</span>
        </p>
      </form>
    </div>
  );
};
export default Login;
