import React, { useState } from 'react';
import Collapsible from 'react-collapsible';
import Layout from "~/components/global/Layout";
import { api } from "~/utils/api";
// ... (other imports and code)

const Settings: React.FC = () => {
  const [apiKey, setApiKey] = useState({
    username: '',
    apiKey: {
      name: '',
      key: '',
      iv: '',
    },
  });

  const [password, setPassword] = useState({
    oldPass: '',
    newPass: '',
    newConfirm: '',
  });

  const addAPIKeys = api.user.addUserApiKey.useMutation();
  const changePassword = api.user.changeUserPass.useMutation();

  const handleAddApiKey = async () => {
    try {
      await addAPIKeys.mutate({ ...apiKey });
    } catch (error) {
      console.error('Error adding API key:', error);
    }
  };

  const handleChangePassword = async () => {
    try {
      await changePassword.mutate({ ...password, username: apiKey.username });
      // Optionally, you can handle success here, e.g., show a success message.
    } catch (error) {
      // Handle errors, e.g., show an error message.
      console.error('Error changing password:', error);
    }
  };

  return (
    <Layout>
      <div className="flex flex-col justify-center items-center h-full">
        <Collapsible trigger="Account">

        </Collapsible>
        <Collapsible trigger="Privacy and Security">
          {/* Privacy and Security content here */}
          <p>Privacy and Security</p>

          <p>ADD API KEYS</p>
          <input
            type="text"
            placeholder="Username"
            value={apiKey.username}
            onChange={(e) => setApiKey({ ...apiKey, username: e.target.value })}
          />
          <input
            type="text"
            placeholder="API Key Name"
            value={apiKey.apiKey.name}
            onChange={(e) => setApiKey({ ...apiKey, apiKey: { ...apiKey.apiKey, name: e.target.value } })}
          />
          <input
            type="text"
            placeholder="API Key"
            value={apiKey.apiKey.key}
            onChange={(e) => setApiKey({ ...apiKey, apiKey: { ...apiKey.apiKey, key: e.target.value } })}
          />
          <input
            type="text"
            placeholder="IV"
            value={apiKey.apiKey.iv}
            onChange={(e) => setApiKey({ ...apiKey, apiKey: { ...apiKey.apiKey, iv: e.target.value } })}
          />
          <button onClick={handleAddApiKey}>Add API Key</button>

          {/* Change Password feature */}
          <p>CHANGE PASSWORD</p>
          <input
            type="password"
            placeholder="Old Password"
            value={password.oldPass}
            onChange={(e) => setPassword({ ...password, oldPass: e.target.value })}
          />
          <input
            type="password"
            placeholder="New Password"
            value={password.newPass}
            onChange={(e) => setPassword({ ...password, newPass: e.target.value })}
          />
          <input
            type="password"
            placeholder="Confirm New Password"
            value={password.newConfirm}
            onChange={(e) => setPassword({ ...password, newConfirm: e.target.value })}
          />
          <button onClick={handleChangePassword}>Change Password</button>
        </Collapsible>

        <Collapsible trigger="Help and Support">
          <p>Contact Mr. Girouard</p>
        </Collapsible>
      </div>
    </Layout>
  );
};

export default Settings;
