import React, { useState } from "react";
import Link from "next/link";
import { useRouter } from "next/router";
import CustomInput from "~/components/CustomInput";
import { IoReturnDownBackOutline } from "react-icons/io5";
import { api } from "~/utils/api";

const Signup: React.FC = () => {
  const [ username, setUserName ] = useState<string>("");
  const [ email, setEmail ] = useState<string>("");
  const [ password, setPassword ] = useState<string>("");

  const mutation = api.login.create_account.useMutation({
    onSuccess: async () => {
      alert("Registration Complete! Now login.");
      await router.push("/Login");
    },
    onError: (error) => {
      console.log(error);
    },
  });

  const router = useRouter();

  const returnHome = () => {
    router.push("/")
			.catch((err) => console.log(`Failed to navigate to home page with error: ${err}`));
  };
  const goToLogin = () => {
    router.push("/Login")
      .catch((err) => console.log(`Failed to navigate to login page with error: ${err}`));
  };
  const signup = (event: React.FormEvent) => {
    event.preventDefault();
    mutation.mutate({
      email: email,
      username: username,
      password: password,
    });
  };

  return (
    <div className="signup-container">
      <IoReturnDownBackOutline onClick={returnHome} className="return" />
      <div className="header">
        <div className="signup-logo">
          <img src="/finvis_logo.png" alt="finvis logo" />
        </div>
        <h1>FinVis</h1>
      </div>
      <form onSubmit={signup} className="signup-form" action="POST">
        <CustomInput
          type="text"
          onChange={(e) => {
            setUserName(e.target.value);
          }}
          placeholder="Username"
          required
        />
        <CustomInput
          type="email"
          onChange={(e) => {
            setEmail(e.target.value);
          }}
          placeholder="Email"
          required
        />
        <CustomInput
          type="password"
          onChange={(e) => {
            setPassword(e.target.value);
          }}
          placeholder="Password"
          required
        />
        <input type="submit" value="Create Account" />
        <p className="go-to-login">
          Already Have an Account? <span onClick={goToLogin}>Go to Login</span>
        </p>
      </form>
    </div>
  );
};
export default Signup;
